version 14.1
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
	log close 
	}
log using exercise03nonph.log, text replace


/*		************************************************************	*/
/*     	File Name:		exercise03nonph.do								*/
/*     	Date:   		May 2, 2019 									*/
/*      Author: 		Frederick J. Boehmke							*/
/*      Purpose:		Check for nonproportion hazards in the NAFTA 	*/
/*						position taking data. This also introduces TVCs	*/
/*      Input File:		exercise03nonph.dta								*/
/*      Output File:	exercise03nonph.log								*/	
/*      				exercise03nonph-surv-yes.dta					*/	
/*      				exercise03nonph-surv-no.dta						*/
/*      				exercise03nonph.gph								*/
/*      Requires:		estout.ado										*/		
/*		************************************************************	*/

	/************************************************/
	/* Read in the data, summarize, and -stset- it.	*/
	/************************************************/

	
use exercise03nonph, clear

  summarize

  stset timing
  
	stsum
	stdescribe

  
	/******************/
	/* Run the model. */
	/******************/


streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, dist(weibull) nohr
stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr

  
	/************************************************/
	/* Test the proportional hazards assumption. 	*/
	/************************************************/

	
estat phtest, detail

estat phtest, plot(mexbordr)
estat phtest, plot(corptpct)
estat phtest, plot(hhcenter)

		/* Interact mexbordr with ln(t) using tvc(option). */
		/* Note that this means time varying effect, not a 	*/
		/* time varying covariate more generally. */
  
stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr ///
	tvc(mexbordr) texp(ln(_t))

		/* Graph the effect on the hazard exp(b+b*ln(t)). */
		
  twoway function y = exp([main]_b[mexbordr] + [tvc]_b[mexbordr]*ln(x)), range(0 463) ///
	xline(463) ///
	xlabel(0(50)400 463 "Vote" 500) ///
	xtitle(Timing of Position Taking) ///
	ytitle(Proportional Change in the Hazard) ///
	title(Effect of Being from a District Bordering Mexico Over Time)

		/* Do it the wrong way by hand, ignoring that time is a TVC. */
	
generat mexbordr_lnt = mexbordr*ln(timing)
	
stcox corptpct labtpct mexbordr mexbordr_lnt dleader rleader ncomact ideol pscenter hhcenter, nohr

		/* Graph the effect on the hazard exp(b+b*ln(t)). */
		/* Adjust the range to make it easier to see. */
		
  twoway function y = exp(_b[mexbordr] + _b[mexbordr_lnt]*ln(x)), range(10 463) ///
	xline(463) ///
	xlabel(0(50)400 463 "Vote" 500) ///
	xtitle(Timing of Position Taking) ///
	ytitle(Proportional Change in the Hazard) ///
	title(Effect of Being from a District Bordering Mexico Over Time)

	
	/****************************************************************/
	/* Now do it the right way by hand by creating a TVC data 		*/
	/* set. Note that we would need to specify -stplt- differently	*/
	/* for a parametric model. See -help tvc note- in Stata. 		*/
	/****************************************************************/
	
		/* We'll need a couple extra variables. */
		
generate id = _n
generat fail = 1

		/* -stset- with an id so we can then -stsplit-. */

stset timing, id(id) failure(fail)

		/* Let's rerun the model to make sure nothing has changed. */
  
	stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr

		/* Now use -stsplit- to create one observation at each failure point. */
		/* Recall that the Cox model only needs data at failure points. */
  
stsplit, at(failures)
  
		/* Let's rerun the model again to make sure nothing has changed. */
  
  stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, nohr

		/* Generate our time varying effect and add it in to the model. */

  replace mexbordr_lnt = mexbordr*ln(timing)
		
	stcox corptpct labtpct mexbordr mexbordr_lnt dleader rleader ncomact ideol pscenter hhcenter, nohr
	
		/* Graph the effect on the hazard exp(b+b*ln(t)). */
		/* No need to adjust the range to make it easier to see. */
		
  twoway function y = exp(_b[mexbordr] + _b[mexbordr_lnt]*ln(x)), range(1 463) ///
	xline(463) ///
	xlabel(0(50)400 463 "Vote" 500) ///
	xtitle(Timing of Position Taking) ///
	ytitle(Proportional Change in the Hazard) ///
	title(Effect of Being from a District Bordering Mexico Over Time)
	
log close
clear
exit, STATA
